#
# spec file for package perl-Glib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Glib
Name:           perl-Glib
Version:        1.3294
Release:        1.5
#Upstream:  This library is free software; you can redistribute it and/or modify it under the terms of the Lesser General Public License (LGPL). For more information, see http://www.fsf.org/licenses/lgpl.txt
License:        LGPL-2.1-or-later
Summary:        Perl wrappers for the GLib utility and Object libraries
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/X/XA/XAOC/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::Depends) >= 0.300
BuildRequires:  perl(ExtUtils::PkgConfig) >= 1.000
Requires:       perl(ExtUtils::Depends) >= 0.300
Requires:       perl(ExtUtils::PkgConfig) >= 1.000
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  glib2-devel >= 2.0.0
# MANUAL END

%description
This wrapper attempts to provide a perlish interface while remaining as
true as possible to the underlying C API, so that any reference materials
you can find on using GLib may still apply to using the libraries from
perl. This module also provides facilities for creating wrappers for other
GObject-based libraries. The SEE ALSO section contains pointers to all
sorts of good information.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc AUTHORS ChangeLog.pre-git doctypes Glib.exports NEWS perl-glib.doap README TODO xsapi.pod.foot xsapi.pod.head
%license LICENSE

%changelog
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.3294
  see /usr/share/doc/packages/perl-Glib/ChangeLog.pre-git
* Sun Jun  7 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.3293
  see /usr/share/doc/packages/perl-Glib/ChangeLog.pre-git
* Thu Feb 20 2020 Tina Müller <tina.mueller@suse.com>
- Add manual license LGPL-2.1-or-later to cpanspec.yml
* Wed Feb 19 2020 <timueller+perl@suse.de>
- updated to 1.3292
  see /usr/share/doc/packages/perl-Glib/ChangeLog.pre-git
* Wed Aug 28 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Removed patch fixed upstream:
  * perl-Glib-1.328-glib2.59-comment-linebreaks.patch
* Wed Aug 28 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.3291
  see /usr/share/doc/packages/perl-Glib/ChangeLog.pre-git
* Tue Aug 27 2019 Tina Mueller <tina.mueller@suse.com>
- Add patch and glib2-devel dependency to cpanspec.yml
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.329
  see /usr/share/doc/packages/perl-Glib/ChangeLog.pre-git
* Fri Mar 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add perl-Glib-1.328-glib2.59-comment-linebreaks.patch: Fix build
  with new glib2. Patch from fedora.
* Mon Oct  8 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Thu Sep 27 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.328
  see /usr/share/doc/packages/perl-Glib/ChangeLog.pre-git
* Wed Sep 12 2018 pmonrealgonzalez@suse.com
- Update to version 1.326
  * Fix typo in pod: s/atomical/atomic/ (Bugzilla #784155)
* Mon Mar  5 2018 bwiedemann@suse.com
- Update to version 1.326
  * Allow overriding of current time in generated man-pages (boo#1047218)
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 1.325 (changes since 1.321):
  * Fix typos (bgo#760065).
  * Docs: Add missing blurbs for the benefit of "whatis"
    (bgo#753466).
  * Fix a POD error in the Glib::ParamSpec whatis entry.
  * Fix POD for the benefit of "whatis" (bgo#772329).
  * Fix typos in error message and POD (bgo#772328).
  * Try to avoid a possible hang in t/9.t.
  * Handle removing '.' in @INC for perl-5.26.0 compatibility.
- Provide perl-Glib-devel as there are some header files in the
  package.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 1.321:
  * GBoxed.xs: Check Glib version prior to enabling GBoxed types.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 1.320:
  * Makefile.PL: Add IRC link to metadata block.
  * Glib::GenPod: Supply default namespace blurbs.
  * Properly escape dash in generated API index POD.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 1.314:
  * Fix compilation on libglib < 2.26.
  * Add Glib::Bytes, a wrapper for GBytes.
  * Sort the output of podify_signals in a deterministic way.
* Thu Aug 20 2015 sor.alexei@meowr.ru
- Update to 1.313:
  * Fix compilation and test issues with Glib::Variant::ParseError.
  * Add a short explanatory comment to the lazy-loading system.
* Fri Jul 17 2015 sor.alexei@meowr.ru
- Update to 1.312 (changes since 1.310):
  * Fix Glib::Variant::classify on big-endian machines.
  * Fix incorrect version in Glib::GenPod.
* Thu Mar 26 2015 sor.alexei@meowr.ru
- Update to 1.310 (changes since 1.305):
  * Add code comments about the peculiar Glib::InitiallyUnowned
    sink handling.
  * Add Glib::Variant and Glib::VariantType.
  * Add char_byte and char_byte_ornull typemaps.
  * Reorder and reformat our header and typemap a little.
  * Hush a compiler warning in GMainLoop.xs.
* Tue Sep 16 2014 coolo@suse.com
-A updated to 1.305
  * Disable the warning message when handing callbacks over to the main loop.
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.304
  * Fix compilation against glib < 2.34.0.
* Mon Dec  9 2013 coolo@suse.com
- updated to 1.303
  * Revert the change to ref counting of initial wrappers of custom subclasses,
  introduced in Glib 1.300.  It caused issues with subclasses inheriting from
  Glib::InitiallyUnowned.
  * Fix a test failure with perl >= 5.19.4.
  * Create a GType for GSpawnFlags and register it with the bindings.
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.302
  * Avoid misusing the macro PL_na, thus preventing issues when Glib is used in
  conjunction with certain XS modules, among them XML::Parser and
  String::Approx.
  * Avoid memory corruption when registering boxed synonyms repeatedly.
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.301
  * t/options.t: skip tests in non-UTF-8 locales; fixes RT#83490
* Wed Jun  5 2013 coolo@suse.com
- updated to 1.300
  * Stable release to coincide with the release of Perl 5.18.0
  Since 1.28x (The previous stable release)
  - ----------------------------------------
  * Ensure timely destruction of initial wrapper of custom subclasses
  * Start changing module version numbers in all Perl modules in the
    distribution, not just lib/Glib.pm; (Bugzilla #690464)
  * Make Glib::Object subclassing more robust.  This should in particular fix
    issues revealed by the change to hash randomization introduced in perl
    5.17.6.
  * Correctly handle utf8-encoded strings in GPerlArgv.  This should fix issues
    seen with utf8-encoded strings in @ARGV with, for example, Gtk2->init.
  Overview of changes in Glib 1.291 (unstable)
  ============================================
  * Ensure timely destruction of initial wrapper of custom subclasses
  * Start changing module version numbers in all Perl modules in the
  distribution, not just lib/Glib.pm; (Bugzilla #690464)
  Overview of changes in Glib 1.290 (unstable)
  ============================================
  * Make Glib::Object subclassing more robust.  This should in particular fix
  issues revealed by the change to hash randomization introduced in perl
  5.17.6.
  * Correctly handle utf8-encoded strings in GPerlArgv.  This should fix issues
  seen with utf8-encoded strings in @ARGV with, for example, Gtk2->init.
  Overview of changes in Glib 1.280 (stable)
  ==========================================
  Since 1.26x (the previous stable series)
  - ---------------------------------------
  * Correctly handle the boxed type for GError.
  * Ensure that custom signal marshallers are always used irregardless of
    the spelling used for the signal name.
  * Make the stack handling of some marshallers more robust, in
    preparation for custom Glib::Boxed converters that call back into
    Perl code.
  * Add new C API gperl_register_boxed_synonym.
* Sat Jul 21 2012 coolo@suse.com
- disable test suite, creates bigger problems than it helps atm
* Mon Jan 23 2012 vcizek@suse.com
- update to 1.250
  * Add a fallback implementation of SvMAGIC_set; Bugzilla bug #665266
  * Avoid a syntax error on older perls
  * Glib::Object: make ref-counting compatible with perl >= 5.16 (RT#73650)
  * Fix some typos in POD (RT#73616)
* Mon Jan  2 2012 vcizek@suse.cz
- update to 1.242
  * Changed addresses in GPL license notices
  * Glib::GenPod: fix typo in default pspec values
  * Glib::GenPod: delete a duplicate key in %%basic_types
* Mon Nov 21 2011 vcizek@suse.com
- update to 1.241
  * Fix a test failure in t/GtkEntryBuffer.t
  * Fix a test failure in t/tied-objects.t
  * Add the missing NEWS entries from the stable branch.
* Mon Oct 17 2011 vcizek@suse.com
- update to 1.240
  * Add Glib::Param::GType support.
  * Add Glib::Log->set_default_handler() and
    Glib::Log::default_handler().
  * Add Glib::ParamSpec->override() and get_redirect_target().
  * Add Glib::Param->get_default_value().
  * Support the fundamental type Glib::GType.
  * Correctly handle variables with "magic" attached, like tied
    variables.
  * Don't copy boxed objects when passing from Perl to C.
* Thu Aug  4 2011 vcizek@novell.com
- update to 1.224
  Glib::ParamSpec->value_validate(): copy boxed objects if necessary
  Fix a test failure
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Jul 16 2010 anicka@suse.cz
- update to 1.223
  * Fix a few test failures.
* Fri Jan 15 2010 anicka@suse.cz
- update to 1.222
  * Properly handle slashes in copyright footers passed to
  Glib::MakeHelper.
  * Fix a test failure on s390.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Mar 30 2009 anicka@suse.cz
- update to 1.221
  * test fixes
* Wed Mar 18 2009 anicka@suse.cz
- update to 1.220
  * GType.xs (gperl_fundamental_type_from_obj): Check the SV for
  definedness before passing it to SvRV.
  * GClosure.xs (gperl_closure_marshal): Synchronize the way signals
  with no return value are handled with how it's done in
  gperl_signal_class_closure_marshal.  This means that Perl handlers
  for these kinds of signals are now always called in void context,
  as they should be.
  * gperl.h: Provide gperl_register_boxed_alias,
  gperl_register_fundamental_alias, and gperl_register_object_alias
  to register aliases for other registered types.  An alias is a
  package name that will resolve to the specified type, while the
  type will still resolve to its originally registered package when
  going the other way.
  * Glib.pm: Add constants Glib::SOURCE_CONTINUE and SOURCE_REMOVE
  for use in source-type callbacks.
  * test fixes, docs fixes
* Mon Oct  6 2008 anicka@suse.cz
- update to 1.200
  * GClosure.xs (gperl_callback_invoke): Instead of putting a mortal
  copy of the user data on the stack, increment its ref count and
  mortalize it.  This ensure that modifications to $_[-1] in the
  callback actually change the user data.  Patch by Kevin Ryde.
  * GValue.xs: Handle NULL GParamSpecs in newSVGParamSpec by
  returning undef.  Consequently, remove the NULL handling in
  _gperl_sv_from_value_internal.
  * GType.xs (gperl_convert_flag_one, gperl_convert_flags): Improve
  the wording of the error messages for invalid flags a bit.
  * GValue.xs (_gperl_sv_from_value_internal): Handle NULL
  GParamSpecs gracefully by returning undef.
  * GParamSpec.xs (newSVGParamSpec): Croak on NULL GParamSpecs.
  * GParamSpec.xs: Add hierarchy POD sections to the various
  Glib::ParamSpec subclasses.
  * GenPod.pm: Document how to hide arguments with "=for arg".  Cope
  with _noinc_ornull type variants.
  * GObject.xs (g_object_new): Check that we got a correct number of
  arguments.
  * test fixes
* Thu Jun 19 2008 anicka@suse.cz
- update to 1.183
  * GSignal.xs: In the xsub for g_signal_add_emission_hook,
  make sure that the type class exists before we try to
  fetch information about one of its signals.
  * t/c.t: Overload '!=' and 'ne' for flags values for consistency.
  * GClosure.xs (gperl_callback_invoke): Put a mortal copy of the
  user data on the stack to avoid prematurely destroying it in
  certain cases.  Patch by Kevin Ryde.
  * t/c.t: Test that empty flags values ([], undef) work.
  * GType.xs (gperl_convert_flag_one): Don't call
  gperl_type_flags_get_values needlessly.
  * GType.xs: Use const char* to store the return value of
  sv_reftype.
  * Subclass.pm: Improve the documentation of GET_PROPERTY and
  SET_PROPERTY.  (Patch by Kevin Ryde)
  * t/c.t: Register Glib::Enum and Glib::Flags.  Remove special case
  logic for these from Glib::Type::register().
* Wed Apr  9 2008 anicka@suse.cz
- update to 1.182
  * GType.xs: For the 64 bit integer converters: use
  g_ascii_strtoll, g_ascii_strtoull, and _atoi64 when available.
  Only use _strtoi64 and _strtoui64 if _MSC_VER >= 1300.
  * GenPod.pm: Add setters set_copyright, set_year, set_authors, and
  set_main_mod for the corresponding package variables.
* Mon Mar 24 2008 anicka@suse.cz
- update to 1.181
  * Makefile.PL: Remove the no_index specification from EXTRA_META
  because the YAML implementations currently in use don't seem to
  support this syntax yet.
  * Makefile.PL (MY::postamble): Handle the EU::Depends object $glib
  being undefined gracefully.
  * Makefile.PL: Don't warn about this release being unstable
  because it isn't.
  * copyright.pod: Update for 2008.
* Thu Mar 13 2008 anicka@suse.cz
- update to 1.180
  * Makefile.PL: Tell the compiler to always look for headers in '.'
  first so that ours are preferred in case of name
  clashes.
  * ParseXSDoc.pm (parse_file): When parsing an #else pre-processor
  directive, make sure we have actually seen and parsed a
  corresponding #if before trying to negate its entry.  This can
  happen when our parsing heurestics fail.  The result was an
  exception: "Modification of non-creatable array value attempted."
  * GType.xs:  Defer the instantiation of a newly-registered
  object class's class until after we've parsed the list of
  signals, properties, and interfaces to add to it.  This
  allows perl-derived GObjects to override GInterfaces that
  are implemented by parent classes.
  * GObject.xs:  Load GInterface types immediately, instead of
  leaving them for lazy loading.  Otherwise, it is possible to
  get into situations in which a GInterface has not triggered
  its lazy loading by the time it is needed.
  * GObject.xs (class_info_finish_loading): When handling a class'
  @ISA, instead of simple av_fetch calls and a final av_clear, use
  repeated av_shift calls. Invoking av_clear on an @ISA array seems
  to break the caching magic associated with it when running under
  perl 5.10.0.  This in turn breaks our lazy-loading scheme.
  * Glib.xs: Use gperl_sv_defined instead of SvOK to check SVs for
  definedness.  This keeps Glib from erroneously thinking your
  scalars are undefined, for example when using tied hashes.
  * GType.xs: Define and use PORTABLE_LL_FORMAT and
  PORTABLE_ULL_FORMAT.
* Mon Jan 14 2008 anicka@suse.cz
- update to 1.164
  * GType.xs:  Defer the instantiation of a newly-registered
  object class's class until after we've parsed the list of
  signals, properties, and interfaces to add to it.
  * GObject.xs:  Load GInterface types immediately, instead of
  leaving them for lazy loading.
  * ParseXSDoc.pm (parse_file): When parsing an #else pre-processor
  directive, make sure we have actually seen and parsed a
  corresponding #if before trying to negate its entry.
  * GObject.xs (class_info_finish_loading): When handling a class'
  @ISA, instead of simple av_fetch calls and a final av_clear,
    use repeated av_shift calls.
  * GBookmarkFile.xs: Hush compiler warning.
  * GError.xs (gperl_gerror_from_sv): Fix the check for undefined
  domain keys in GError hashes.
  * GType.xs (add_interfaces): Fix the check for undefined
  interface names.
* Wed Nov 21 2007 anicka@suse.cz
- update to 1.162
  * MakeHelper.pm (postamble_docs_full): When constructing the
    add_types call, make sure to properly quote the paths.
* Thu Nov  1 2007 anicka@suse.cz
- update to 1.161
  * Makefile.PL: Use BEGIN { require 5.008; } instead of use 5.008;
    so automatic CPAN testers know which perl version we need. Also
    get rid of the MY package by prefixing the relevant subs with
  `MY::´.
  * GObject.xs (Glib::Object::CLONE): Check that perl_gobjects !=
    NULL before working with it, to avoid an assertion.
* Fri Oct  5 2007 anicka@suse.cz
- update to 1.160
  * GenPod.pm: Output a warning if a type name isn't recognized by
    the doc parser.  Add 'package' and 'list' to the basic types and
    fix the remaining type name issues the new warning uncovered.
  * ParseXSDoc.pm: Parse preprocessor conditionals in the XS code to
    add Since: tags to methods' POD.
  * ParseXSDoc.pm: Make it possible to document specific packages in
    different POD files by providing a new =for object variant.
  * GObject.xs: Register G_TYPE_INTERFACES as Glib::Interfaces to
    avoid having it appear under Glib::Object::_Unregistered in
    hierarchies in the generated POD.
  * test fixes
- do not ignore test results anymore (package builds fine on all
  supported archs)
* Mon Feb 26 2007 anicka@suse.cz
- update to 1.144
  * MakeHelper.pm: Use BSD make syntax for the BLIB_DONE stuff on
  BSD systems, unless the environment variable FORCE_GMAKE is set.
* Wed Feb 14 2007 anicka@suse.cz
- update to 1.143
  * Makefile.PL: Check that glib >= 2.12.0, not 2.11.0, before
    including GBookmarkFile.xs.
  * Glib.xs: Call g_threads_init before g_type_init.  Required (and
    probably enforced in the near future) by recent glib versions.
* Tue Dec 12 2006 anicka@suse.cz
- update to 1.142
  * bugfixes, test fixes
  * GType.xs: Add macros, PORTABLE_STRTOLL and PORTABLE_STRTOULL,
    to centralize the preprocessor madness for 64bit integer
    support.
* Thu Sep  7 2006 anicka@suse.cz
- update to 1.140
  * bugfixes and fixes in tests
* Fri Jul 21 2006 anicka@suse.cz
- update to 1.120
  * add a new header file for private
    functions that are used in more than one xs file
  * bugfixes
- remove last patch (fixed in upstream)
* Tue Mar 21 2006 schwab@suse.de
- Fix broken casts.
* Mon Jan 30 2006 ro@suse.de
- fixed missing ";" in GType.xs
- ignore failed test for the moment
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update to 1.102
* Thu Nov 10 2005 anicka@suse.cz
- update to 1.101
* Fri Jul 29 2005 mjancar@suse.cz
- update to 1.082
* Wed Jun 22 2005 ro@suse.de
- update to 1.081
- removed G_PARAM_PRIVATE (removed from glib2)
* Fri Jan 21 2005 ro@suse.de
- update to 1.072
* Tue Nov  2 2004 mcihar@suse.cz
- initial packaging
